@@ -284,13 +284,13 @@ class ResponseObject(object):
 		delattr(self, key)
 	# string format.
 	def __str__(self):
-		return self.json()
 		return json.dumps(self.dict(), indent=4)
 		if isinstance(self, dict):
 			return json.dumps(self, indent=4)
 		else:
 			return json.dumps(self.dict(), indent=4)
 	def json(self,):
+		return json.dumps(self)
 		return json.dumps(self, default=lambda o: o.__dict__)
 	#def __dict__(self):
 	#	return json.dumps(self.dict(), indent=4)
